@@ -40,15 +40,18 @@ class Client:
         }
         if self.get_limit == 0:
             time.sleep(self.get_timeout + 0.2)
-        try:
-            with self.__http.get(self.base + "/get_pixel", headers = self.headers, params=data) as resp:
-                data = resp.json()
-                headers = resp.headers
+
+        with self.__http.get(self.base + "/get_pixel", headers = self.headers, params=data) as resp:
+            data = resp.json()
+            headers = resp.headers
+            try:
                 self.get_limit = int(headers["requests-remaining"])
                 self.get_timeout = int(headers["requests-reset"])
-                return int(f"0x{data['rgb']}", base=16)
-        except KeyError:
-            raise RateLimitError("Rate limited by server but internal values not updated.")
+            except KeyError:
+                self.get_limit = 0
+                self.get_timeout = int(headers['cooldown-reset'])
+                raise RateLimitError(f"Rate limited by server but internal values not updated. Please wait {headers['cooldown-reset']}")
+            return int(f"0x{data['rgb']}", base=16)
     
     def get_canvas(self, scale=1):
         """
@@ -64,19 +67,22 @@ class Client:
             raise TypeError("Scale must be a positive integer")
         if self.gets_limit == 0:
             time.sleep(self.gets_timeout+ 0.2)
-        try:
-            with self.__http.get(self.base + "/get_pixels", headers=self.headers) as resp:
-                stream = bytes(resp.content)
-                headers = resp.headers
+        with self.__http.get(self.base + "/get_pixels", headers=self.headers) as resp:
+            stream = bytes(resp.content)
+            headers = resp.headers
+            try:
                 self.gets_limit = int(headers["requests-remaining"])
                 self.gets_timeout = int(headers["requests-reset"])
-                with self.__http.get(self.base + "/get_size", headers= self.headers) as resps:
-                    size = resps.json()
-                    im =  Image.frombytes(mode="RGB", size=(size['width'], size['height']), data=stream)
-                    im = im.resize((im.size[0]*scale, im.size[1]*scale), Image.NEAREST)
-                    return im
-        except KeyError:
-            raise RateLimitError("Rate limited by server but internal values not updated.")
+            except KeyError:
+                self.gets_limit = 0
+                self.gets_timeout = int(headers['cooldown-reset'])
+                raise RateLimitError(f"Rate limited by server but internal values not updated. Please wait {headers['cooldown-reset']}")
+            with self.__http.get(self.base + "/get_size", headers= self.headers) as resps:
+                size = resps.json()
+                im =  Image.frombytes(mode="RGB", size=(size['width'], size['height']), data=stream)
+                im = im.resize((im.size[0]*scale, im.size[1]*scale), Image.NEAREST)
+                return im
+
 
 
     
@@ -90,12 +96,9 @@ class Client:
         Returns:
         tuple - The width and height of the canvas
         """
-        try:
-            with self.__http.get(self.base + "/get_size", headers=self.headers) as resp:
-                data = resp.json()
-                return (data["width"], data["height"])
-        except KeyError:
-            raise RateLimitError("Rate limited by server but internal values not updated.")
+        with self.__http.get(self.base + "/get_size", headers=self.headers) as resp:
+            data = resp.json()
+            return (data["width"], data["height"])
 
     def set_pixel(self, x: int, y: int, color: int):
         """
@@ -116,15 +119,18 @@ class Client:
         }
         if self.post_limit == 0:
             time.sleep(self.post_timeout + 0.2)
-        try:
-            with self.__http.post(self.base + "/set_pixel", headers=self.headers, json=data) as resp:
-                headers = resp.headers
+        with self.__http.post(self.base + "/set_pixel", headers=self.headers, json=data) as resp:
+            headers = resp.headers
+            print(headers)
+            try:
                 self.post_limit = int(headers["requests-remaining"])
                 self.post_timeout = int(headers["requests-reset"])
-                return
-        except KeyError:
-            raise RateLimitError("Rate limited by server but internal values not updated.")
-    
+            except KeyError:
+                self.set_limit = 0
+                self.set_timeout = int(headers['cooldown-reset'])
+                raise RateLimitError(f"Rate limited by server but internal values not updated. Please wait {headers['cooldown-reset']}")
+            return
+
     def get_limits(self):
         """
         Return the last known rate limits of the API. These are refreshed every request.
@@ -145,4 +151,5 @@ class Client:
         }
         return limits
     
-
+client = Client("eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjIzNDY0OTk5MjM1NzM0NzMyOCIsInNhbHQiOiJ5ak56RUlia1Vzc3VGaHNDaUNzcl93In0.TlnN_oFjyvUMrfVlLZo0bQby0gRZ6THxrQM6L4eUisk")
+client.set_pixel(0,0,0xFFFFFF)
